@@ -20,6 +20,7 @@ from dataclasses import dataclass, field
 from pathlib import Path
 from typing import Dict, List, Optional, Union, no_type_check
 
+import requests  # type: ignore
 import validators  # type: ignore
 
 from ..config import AVAILABLE_AUDIO_FORMATS, AVAILABLE_GENERIC_FORMATS
@@ -38,6 +39,9 @@ class BaseSource:
         Path to the local file, by default None.
     url : Optional[str], optional
         URL to the remote file, by default None.
+    url_headers : Optional[Dict[str, str]], optional
+        Headers to retrieve the file from the URL, by default None.
+        Useful if the file requires authentication to be retrieved.
 
     Raises
     ------
@@ -69,6 +73,7 @@ class BaseSource:
 
     filepath: Optional[Union[str, Path]] = field(default=None, repr=False)
     url: Optional[str] = field(default=None, repr=False)
+    url_headers: Optional[Dict[str, str]] = field(default=None, repr=False)
     source: str = field(init=False)
     source_type: str = field(init=False)
     _stem: str = field(init=False, repr=False)
@@ -107,11 +112,11 @@ class BaseSource:
             self.source_type = "local"
 
         if self.url:
-            if not validators.url(self.url):
-                raise ValueError(
-                    f"Please provide a valid URL. {self.url} is not valid."
-                )
-            self.source_type = "remote"
+            if self._check_if_url_is_valid():
+                filename = self.url.split("/")[-1]
+                self._stem = filename.split(".")[0]
+                self._suffix = f".{filename.split('.')[1].split('?')[0]}"
+                self.source_type = "remote"
 
     @no_type_check
     def _load_file_from_path(self) -> bytes:
@@ -119,9 +124,21 @@ class BaseSource:
         with open(self.filepath, "rb") as f:
             return f.read()
 
-    def _load_file_from_url(self) -> bytes:
+    def _load_file_from_url(self) -> requests.Response.content:
         """Load file from URL."""
-        raise NotImplementedError("Loading files from URLs is not implemented yet.")
+        if self.url_headers:
+            file = requests.get(self.url, headers=self.url_headers)
+        else:
+            file = requests.get(self.url)
+
+        return file.content
+
+    def _check_if_url_is_valid(self) -> bool:
+        """Check if URL is valid."""
+        if not validators.url(self.url):
+            raise ValueError(f"Please provide a valid URL. {self.url} is not valid.")
+
+        return True
 
     def prepare_payload(self) -> Union[str, Dict[str, bytes]]:
         """Prepare payload."""
@@ -263,15 +280,14 @@ class GenericSource(BaseSource):
         """Post-init method."""
         super().__post_init__()
         self.source = "generic"
-        if self.source_type == "local":
-            if self._suffix not in AVAILABLE_GENERIC_FORMATS:
-                raise ValueError(
-                    f"Please provide a valid file format. {self._suffix} is not valid."
-                )
-            else:
-                self.file_object = self._load_file_from_path()
 
-        if self.source_type == "remote":
+        if self._suffix not in AVAILABLE_GENERIC_FORMATS:
+            raise ValueError(
+                f"Please provide a valid file format. {self._suffix} is not valid."
+            )
+        if self.source_type == "local":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
             self.file_object = self._load_file_from_url()
 
     def prepare_payload(self) -> str:
@@ -336,15 +352,13 @@ class AudioSource(BaseSource):
         """Post-init method."""
         super().__post_init__()
         self.source = "audio"
+        if self._suffix not in AVAILABLE_AUDIO_FORMATS:
+            raise ValueError(
+                f"Please provide a valid file format. {self._suffix} is not valid."
+            )
         if self.source_type == "local":
-            if self._suffix not in AVAILABLE_AUDIO_FORMATS:
-                raise ValueError(
-                    f"Please provide a valid file format. {self._suffix} is not valid."
-                )
-            else:
-                self.file_object = self._load_file_from_path()
-
-        if self.source_type == "remote":
+            self.file_object = self._load_file_from_path()
+        elif self.source_type == "remote":
             self.file_object = self._load_file_from_url()
 
     def prepare_payload(self) -> Dict[str, bytes]:
